@@ -1,12 +1,12 @@
 """
 V1 Admin Cost Center
 """
-
+from ....internals.list_all_resources import ListAllResources
 from ....internals.list_resources import ListResources
 from ....internals.post_resources import PostResources
 
 
-class CostCenters(ListResources, PostResources):
+class CostCenters(ListResources, ListAllResources, PostResources):
     """Class for Cost Center APIs."""
 
     COST_CENTERS = '/cost_centers'
